@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from mock import Mock
+from .mock import Mock
 
 from testfixtures import wrap, compare
 
